@@ -11,11 +11,17 @@
  *  Synerty Pty Ltd
  *
 """
+from typing import Optional
+
+from peek_platform.file_config.PeekFileConfigHttpServerMixin import (
+    PeekFileConfigHttpMixin,
+)
 from peek_platform.util.LogUtil import (
     setupPeekLogger,
     updatePeekLoggerHandlers,
     setupLoggingToSyslogServer,
 )
+from peek_platform.util.ManHoleUtil import start_manhole
 from peek_plugin_base.PeekVortexUtil import peekFieldName, peekServerName
 from pytmpdir.dir_setting import DirSetting
 from txhttputil.site.FileUploadRequest import FileUploadRequest
@@ -111,8 +117,24 @@ def setupPlatform():
     DirSetting.tmpDirPath = PeekPlatformConfig.config.tmpPath
     FileUploadRequest.tmpFilePath = PeekPlatformConfig.config.tmpPath
 
+    # Setup manhole
+    if PeekPlatformConfig.config.manholeEnabled:
+        start_manhole(
+            PeekPlatformConfig.config.manholePort,
+            PeekPlatformConfig.config.manholePassword,
+            PeekPlatformConfig.config.manholePublicKeyFile,
+            PeekPlatformConfig.config.manholePrivateKeyFile,
+        )
 
-def main():
+
+def main(
+    loadPlugins=True,
+    startPlugins=True,
+    serveSite=True,
+    serveWebsocket=True,
+    httpServerConfig: Optional[PeekFileConfigHttpMixin] = None,
+    siteName="Peek Field Site",
+):
     # defer.setDebugging(True)
     # sys.argv.remove(DEBUG_ARG)
     # import pydevd
@@ -126,7 +148,7 @@ def main():
     importPackages()
 
     # Make the agent restart when the server restarts, or when it looses connection
-    def restart(status):
+    def restart(_):
         from peek_platform import PeekPlatformConfig
 
         PeekPlatformConfig.peekSwInstallManager.restartProcess()
@@ -141,11 +163,15 @@ def main():
     # First, setup the VortexServer Agent
     from peek_platform import PeekPlatformConfig
 
-    d = VortexFactory.createTcpClient(
-        PeekPlatformConfig.componentName,
-        PeekPlatformConfig.config.peekServerHost,
-        PeekPlatformConfig.config.peekServerVortexTcpPort,
-    )
+    if not startPlugins:
+        d = defer.succeed(None)
+
+    else:
+        d = VortexFactory.createTcpClient(
+            PeekPlatformConfig.componentName,
+            PeekPlatformConfig.config.peekServerHost,
+            PeekPlatformConfig.config.peekServerVortexTcpPort,
+        )
 
     # Start Update Handler,
     # Add both, The peek client might fail to connect, and if it does, the payload
@@ -160,18 +186,31 @@ def main():
 
     # Load all Plugins
     d.addErrback(vortexLogFailure, logger, consumeError=True)
-    d.addCallback(lambda _: PeekPlatformConfig.pluginLoader.loadCorePlugins())
-    d.addCallback(
-        lambda _: PeekPlatformConfig.pluginLoader.loadOptionalPlugins()
-    )
+    if loadPlugins:
+        d.addCallback(
+            lambda _: PeekPlatformConfig.pluginLoader.loadCorePlugins()
+        )
+        d.addCallback(
+            lambda _: PeekPlatformConfig.pluginLoader.loadOptionalPlugins()
+        )
 
-    d.addCallback(lambda _: PeekPlatformConfig.pluginLoader.startCorePlugins())
-    d.addCallback(
-        lambda _: PeekPlatformConfig.pluginLoader.startOptionalPlugins()
-    )
+    if startPlugins:
 
-    # Set this up after the plugins have loaded, it causes problems with the ng build
-    d.addCallback(lambda _: setupVortexOfflineSubscriber())
+        d.addCallback(
+            lambda _: PeekPlatformConfig.pluginLoader.startCorePlugins()
+        )
+        d.addCallback(
+            lambda _: PeekPlatformConfig.pluginLoader.startOptionalPlugins()
+        )
+
+    # Set this up after the plugins have loaded,
+    # it causes problems with the ng build
+    if startPlugins:
+        d.addCallback(lambda _: setupVortexOfflineSubscriber())
+
+    # Create the mobile vortex server
+    if not httpServerConfig:
+        httpServerConfig = PeekPlatformConfig.config.fieldHttpServer
 
     def startSite(_):
         from peek_field_service.backend.SiteRootResource import (
@@ -179,53 +218,74 @@ def main():
             fieldRoot,
         )
 
-        setupField()
+        setupField(serveWebsocket=serveWebsocket)
 
-        # Create the mobile vortex server
-        fieldHttpServer = PeekPlatformConfig.config.fieldHttpServer
         setupSite(
-            "Peek Field Site",
+            siteName,
             fieldRoot,
-            portNum=fieldHttpServer.sitePort,
+            portNum=httpServerConfig.sitePort,
             enableLogin=False,
-            redirectFromHttpPort=fieldHttpServer.redirectFromHttpPort,
-            sslBundleFilePath=fieldHttpServer.sslBundleFilePath,
+            redirectFromHttpPort=httpServerConfig.redirectFromHttpPort,
+            sslBundleFilePath=httpServerConfig.sslBundleFilePath,
         )
 
-    d.addCallback(startSite)
+    if serveSite:
+        d.addCallback(startSite)
 
     def startedSuccessfully(_):
         logger.info(
             "Peek Field is running, version=%s",
             PeekPlatformConfig.config.platformVersion,
         )
+        logger.info(
+            "Status - Plugins %s, %s, Site %s, Websocket %s",
+            ("LOADED" if loadPlugins else "NOT LOADED"),
+            ("STARTED" if startPlugins else "NOT STARTED"),
+            ("LISTENING" if serveSite else "DISABLED"),
+            ("LISTENING" if serveWebsocket else "DISABLED"),
+        )
         return _
 
     d.addErrback(vortexLogFailure, logger, consumeError=True)
     d.addCallback(startedSuccessfully)
 
-    reactor.addSystemEventTrigger(
-        "before",
-        "shutdown",
-        PeekPlatformConfig.pluginLoader.stopOptionalPlugins,
-    )
-    reactor.addSystemEventTrigger(
-        "before", "shutdown", PeekPlatformConfig.pluginLoader.stopCorePlugins
-    )
+    if startPlugins:
+        reactor.addSystemEventTrigger(
+            "before",
+            "shutdown",
+            PeekPlatformConfig.pluginLoader.stopOptionalPlugins,
+        )
+        reactor.addSystemEventTrigger(
+            "before",
+            "shutdown",
+            PeekPlatformConfig.pluginLoader.stopCorePlugins,
+        )
 
-    reactor.addSystemEventTrigger(
-        "before",
-        "shutdown",
-        PeekPlatformConfig.pluginLoader.unloadOptionalPlugins,
-    )
-    reactor.addSystemEventTrigger(
-        "before", "shutdown", PeekPlatformConfig.pluginLoader.unloadCorePlugins
-    )
+    if loadPlugins:
+        reactor.addSystemEventTrigger(
+            "before",
+            "shutdown",
+            PeekPlatformConfig.pluginLoader.unloadOptionalPlugins,
+        )
+        reactor.addSystemEventTrigger(
+            "before",
+            "shutdown",
+            PeekPlatformConfig.pluginLoader.unloadCorePlugins,
+        )
 
-    reactor.addSystemEventTrigger("before", "shutdown", VortexFactory.shutdown)
+    if startPlugins:
+        reactor.addSystemEventTrigger(
+            "before", "shutdown", VortexFactory.shutdown
+        )
 
     reactor.run()
 
 
 if __name__ == "__main__":
+    # defer.setDebugging(True)
+    # sys.argv.remove(DEBUG_ARG)
+    # import pydevd
+    # pydevd.settrace(suspend=False)
+
+    setupPlatform()
     main()
